@@ -1,6 +1,8 @@
 #ifndef _SSSD_H_
 #define _SSSD_H_
 
+#include "attr.h"
+
 #define SSSD_DB_PASSWD	0x001
 #define SSSD_DB_GROUP	0x002
 
@@ -11,7 +13,7 @@
 extern int sssd_flush_cache (int dbflags);
 #else
 static inline int
-sssd_flush_cache(int)
+sssd_flush_cache(MAYBE_UNUSED int _1)
 {
 	return 0;
 }
