@@ -198,7 +198,7 @@ static bool shell_is_listed (const char *sh, bool process_selinux)
 
 #else /* without HAVE_VENDORDIR */
 
-static bool shell_is_listed (const char *sh, bool)
+static bool shell_is_listed (const char *sh, MAYBE_UNUSED bool _1)
 {
 	bool found = false;
 	char *cp;
