@@ -109,14 +109,14 @@ static void update_group (struct group *gr);
 static void change_passwd (struct group *gr);
 #endif
 static void log_gpasswd_failure (const char *suffix);
-static void log_gpasswd_failure_system (/*@null@*/void *);
-static void log_gpasswd_failure_group (/*@null@*/void *);
+static void log_gpasswd_failure_system (/*@null@*/MAYBE_UNUSED void *_1);
+static void log_gpasswd_failure_group (/*@null@*/MAYBE_UNUSED void *_1);
 #ifdef SHADOWGRP
-static void log_gpasswd_failure_gshadow (/*@null@*/void *);
+static void log_gpasswd_failure_gshadow (/*@null@*/MAYBE_UNUSED void *_1);
 #endif
 static void log_gpasswd_success (const char *suffix);
-static void log_gpasswd_success_system (/*@null@*/void *);
-static void log_gpasswd_success_group(/*@null@*/void *);
+static void log_gpasswd_success_system (/*@null@*/MAYBE_UNUSED void *_1);
+static void log_gpasswd_success_group (/*@null@*/MAYBE_UNUSED void *_1);
 
 /*
  * usage - display usage message
@@ -472,13 +472,13 @@ static void log_gpasswd_failure (const char *suffix)
 }
 
 static void
-log_gpasswd_failure_system(void *)
+log_gpasswd_failure_system(MAYBE_UNUSED void *_1)
 {
 	log_gpasswd_failure ("");
 }
 
 static void
-log_gpasswd_failure_group(void *)
+log_gpasswd_failure_group(MAYBE_UNUSED void *_1)
 {
 	char  buf[1024];
 
@@ -488,7 +488,7 @@ log_gpasswd_failure_group(void *)
 
 #ifdef SHADOWGRP
 static void
-log_gpasswd_failure_gshadow(void *)
+log_gpasswd_failure_gshadow(MAYBE_UNUSED void *_1)
 {
 	char  buf[1024];
 
@@ -586,13 +586,13 @@ static void log_gpasswd_success (const char *suffix)
 }
 
 static void
-log_gpasswd_success_system(void *)
+log_gpasswd_success_system(MAYBE_UNUSED void *_1)
 {
 	log_gpasswd_success ("");
 }
 
 static void
-log_gpasswd_success_group(void *)
+log_gpasswd_success_group(MAYBE_UNUSED void *_1)
 {
 	char  buf[1024];
 
